http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java 
b/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
index 803badd..197e488 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
@@ -940,9 +940,9 @@ public abstract class GridUtils {
      *
      * @param cls Class to get empty constructor for.
      * @return Empty constructor if one could be found or {@code null} 
otherwise.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    @Nullable public static Constructor<?> forceEmptyConstructor(Class<?> cls) 
throws IgniteCheckedException {
+    @Nullable public static Constructor<?> forceEmptyConstructor(Class<?> cls) 
throws IgniteException {
         Constructor<?> ctor = null;
 
         try {
@@ -957,7 +957,7 @@ public abstract class GridUtils {
                     ctor = (Constructor)ctorFac.invoke(sunRefFac, cls, 
U.objectConstructor());
                 }
                 catch (IllegalAccessException | InvocationTargetException e) {
-                    throw new IgniteCheckedException("Failed to get object 
constructor for class: " + cls, e);
+                    throw new IgniteException("Failed to get object 
constructor for class: " + cls, e);
                 }
         }
 
@@ -969,16 +969,16 @@ public abstract class GridUtils {
      *
      * @param cls Class name.
      * @return Instance.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    @Nullable public static <T> T newInstance(String cls) throws 
IgniteCheckedException {
+    @Nullable public static <T> T newInstance(String cls) throws 
IgniteException {
         Class<?> cls0;
 
         try {
             cls0 = Class.forName(cls);
         }
         catch (Exception e) {
-            throw new IgniteCheckedException(e);
+            throw new IgniteException(e);
         }
 
         return (T)newInstance(cls0);
@@ -989,9 +989,9 @@ public abstract class GridUtils {
      *
      * @param cls Class to instantiate.
      * @return New instance of the class or {@code null} if empty constructor 
could not be assigned.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    @Nullable public static <T> T newInstance(Class<T> cls) throws 
IgniteCheckedException {
+    @Nullable public static <T> T newInstance(Class<T> cls) throws 
IgniteException {
         boolean set = false;
 
         Constructor<T> ctor = null;
@@ -1011,10 +1011,10 @@ public abstract class GridUtils {
             return ctor.newInstance();
         }
         catch (NoSuchMethodException e) {
-            throw new IgniteCheckedException("Failed to find empty constructor 
for class: " + cls, e);
+            throw new IgniteException("Failed to find empty constructor for 
class: " + cls, e);
         }
         catch (InstantiationException | InvocationTargetException | 
IllegalAccessException e) {
-            throw new IgniteCheckedException("Failed to create new instance 
for class: " + cls, e);
+            throw new IgniteException("Failed to create new instance for 
class: " + cls, e);
         } finally {
             if (ctor != null && set)
                 ctor.setAccessible(false);
@@ -1026,10 +1026,10 @@ public abstract class GridUtils {
      *
      * @param cls Class to instantiate.
      * @return New instance of the class or {@code null} if empty constructor 
could not be assigned.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
     @SuppressWarnings({"unchecked"})
-    @Nullable public static <T> T forceNewInstance(Class<?> cls) throws 
IgniteCheckedException {
+    @Nullable public static <T> T forceNewInstance(Class<?> cls) throws 
IgniteException {
         Constructor ctor = forceEmptyConstructor(cls);
 
         if (ctor == null)
@@ -1048,7 +1048,7 @@ public abstract class GridUtils {
             return (T)ctor.newInstance();
         }
         catch (InstantiationException | InvocationTargetException | 
IllegalAccessException e) {
-            throw new IgniteCheckedException("Failed to create new instance 
for class: " + cls, e);
+            throw new IgniteException("Failed to create new instance for 
class: " + cls, e);
         } finally {
             if (set)
                 ctor.setAccessible(false);
@@ -1455,7 +1455,7 @@ public abstract class GridUtils {
             }
 
             if (F.isEmpty(addrs))
-                throw new IgniteCheckedException("No network addresses found 
(is networking enabled?).");
+                throw new IgniteException("No network addresses found (is 
networking enabled?).");
         }
         else
             addresses(locAddr, addrs, hostNames);
@@ -5599,7 +5599,7 @@ public abstract class GridUtils {
     }
 
     /**
-     * Converts {@link InterruptedException} to {@link IgniteCheckedException}.
+     * Converts {@link InterruptedException} to {@link IgniteException}.
      *
      * @param mux Mux to wait on.
      * @throws GridInterruptedException If interrupted.
@@ -6072,9 +6072,9 @@ public abstract class GridUtils {
      * @param c Callable to run.
      * @param <R> Return type.
      * @return Return value.
-     * @throws IgniteCheckedException If call failed.
+     * @throws IgniteException If call failed.
      */
-    @Nullable public static <R> R wrapThreadLoader(ClassLoader ldr, 
Callable<R> c) throws IgniteCheckedException {
+    @Nullable public static <R> R wrapThreadLoader(ClassLoader ldr, 
Callable<R> c) throws IgniteException {
         Thread curThread = Thread.currentThread();
 
         // Get original context class loader.
@@ -6086,11 +6086,11 @@ public abstract class GridUtils {
 
             return c.call();
         }
-        catch (IgniteCheckedException | RuntimeException e) {
+        catch (RuntimeException e) {
             throw e;
         }
         catch (Exception e) {
-            throw new IgniteCheckedException(e);
+            throw new IgniteException(e);
         }
         finally {
             // Set the original class loader back.
@@ -6425,14 +6425,14 @@ public abstract class GridUtils {
      * @param str Input string.
      * @param date Date.
      * @return Next token.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    private static boolean checkNextToken(StringTokenizer t, String str, 
String date) throws IgniteCheckedException {
+    private static boolean checkNextToken(StringTokenizer t, String str, 
String date) throws IgniteException {
         try {
             if (t.nextToken().equals(str))
                 return true;
             else
-                throw new IgniteCheckedException("Invalid date format: " + 
date);
+                throw new IgniteException("Invalid date format: " + date);
         }
         catch (NoSuchElementException ignored) {
             return false;
@@ -6443,9 +6443,9 @@ public abstract class GridUtils {
      *
      * @param str ISO date.
      * @return Calendar instance.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public static Calendar parseIsoDate(String str) throws 
IgniteCheckedException {
+    public static Calendar parseIsoDate(String str) throws IgniteException {
         StringTokenizer t = new StringTokenizer(str, "+-:.TZ", true);
 
         Calendar cal = Calendar.getInstance();
@@ -6521,7 +6521,7 @@ public abstract class GridUtils {
                         cal.set(Calendar.MILLISECOND, 0);
                 }
                 else
-                    throw new IgniteCheckedException("Invalid date format: " + 
str);
+                    throw new IgniteException("Invalid date format: " + str);
             }
             else {
                 cal.set(Calendar.SECOND, 0);
@@ -6530,12 +6530,12 @@ public abstract class GridUtils {
 
             if (!"Z".equals(tok)) {
                 if (!"+".equals(tok) && !"-".equals(tok))
-                    throw new IgniteCheckedException("Invalid date format: " + 
str);
+                    throw new IgniteException("Invalid date format: " + str);
 
                 boolean plus = "+".equals(tok);
 
                 if (!t.hasMoreTokens())
-                    throw new IgniteCheckedException("Invalid date format: " + 
str);
+                    throw new IgniteException("Invalid date format: " + str);
 
                 tok = t.nextToken();
 
@@ -6552,7 +6552,7 @@ public abstract class GridUtils {
                     if (checkNextToken(t, ":", str) && t.hasMoreTokens())
                         tzMin = Integer.parseInt(t.nextToken());
                     else
-                        throw new IgniteCheckedException("Invalid date format: 
" + str);
+                        throw new IgniteException("Invalid date format: " + 
str);
                 }
 
                 if (plus)
@@ -6564,7 +6564,7 @@ public abstract class GridUtils {
                 cal.setTimeZone(TimeZone.getTimeZone("GMT"));
         }
         catch (NumberFormatException ex) {
-            throw new IgniteCheckedException("Invalid date format: " + str, 
ex);
+            throw new IgniteException("Invalid date format: " + str, ex);
         }
 
         return cal;
@@ -6656,13 +6656,13 @@ public abstract class GridUtils {
     }
 
     /**
-     * Casts this throwable as {@link IgniteCheckedException}. Creates wrapping
-     * {@link IgniteCheckedException}, if needed.
+     * Casts this throwable as {@link IgniteException}. Creates wrapping
+     * {@link IgniteException}, if needed.
      *
      * @param t Throwable to cast.
      * @return Grid exception.
      */
-    public static IgniteCheckedException cast(Throwable t) {
+    public static IgniteException cast(Throwable t) {
         assert t != null;
 
         while (true) {
@@ -6675,11 +6675,11 @@ public abstract class GridUtils {
                 continue;
             }
 
-            if (t instanceof IgniteCheckedException)
-                return (IgniteCheckedException)t;
+            if (t instanceof IgniteException)
+                return (IgniteException)t;
 
-            if (!(t instanceof IgniteException) || t.getCause() == null)
-                return new IgniteCheckedException(t);
+            if (!(t instanceof IgniteCheckedException) || t.getCause() == null)
+                return new IgniteException(t);
 
             assert t.getCause() != null; // ...and it is IgniteException.
 
@@ -6991,14 +6991,14 @@ public abstract class GridUtils {
      *
      * @param fut Future.
      * @return Future result.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    public static <T> T get(Future<T> fut) throws IgniteCheckedException {
+    public static <T> T get(Future<T> fut) throws IgniteException {
         try {
             return fut.get();
         }
         catch (ExecutionException e) {
-            throw new IgniteCheckedException(e.getCause());
+            throw new IgniteException(e.getCause());
         }
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
@@ -7006,7 +7006,7 @@ public abstract class GridUtils {
             throw new GridInterruptedException(e);
         }
         catch (CancellationException e) {
-            throw new IgniteCheckedException(e);
+            throw new IgniteException(e);
         }
     }
 
@@ -7226,7 +7226,7 @@ public abstract class GridUtils {
                     try {
                         f.get();
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         U.error(log, "Failed to execute future: " + f, e);
                     }
                 }
@@ -8148,9 +8148,9 @@ public abstract class GridUtils {
      * {@link org.apache.ignite.lifecycle.LifecycleAware} interface and 
executes {@link org.apache.ignite.lifecycle.LifecycleAware#start} method.
      *
      * @param objs Objects.
-     * @throws IgniteCheckedException If {@link 
org.apache.ignite.lifecycle.LifecycleAware#start} fails.
+     * @throws IgniteException If {@link 
org.apache.ignite.lifecycle.LifecycleAware#start} fails.
      */
-    public static void startLifecycleAware(Iterable<?> objs) throws 
IgniteCheckedException {
+    public static void startLifecycleAware(Iterable<?> objs) throws 
IgniteException {
         for (Object obj : objs) {
             if (obj instanceof LifecycleAware)
                 ((LifecycleAware)obj).start();
@@ -8170,7 +8170,7 @@ public abstract class GridUtils {
                 try {
                     ((LifecycleAware)obj).stop();
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     U.error(log, "Failed to stop component (ignoring): " + 
obj, e);
                 }
             }
@@ -8320,13 +8320,13 @@ public abstract class GridUtils {
      * @param addrs Addresses.
      * @param port Port.
      * @return Resolved socket addresses.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
     public static Collection<InetSocketAddress> resolveAddresses(
         IgniteAddressResolver addrRslvr,
         Iterable<String> addrs,
         int port
-    ) throws IgniteCheckedException {
+    ) throws IgniteException {
         assert addrRslvr != null;
 
         Collection<InetSocketAddress> extAddrs = new HashSet<>();
@@ -8341,7 +8341,7 @@ public abstract class GridUtils {
                     if (extAddrs0 != null)
                         extAddrs.addAll(extAddrs0);
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     throw new IgniteSpiException("Failed to get mapped 
external addresses " +
                         "[addrRslvr=" + addrRslvr + ", addr=" + addr + ']', e);
                 }
@@ -8540,14 +8540,14 @@ public abstract class GridUtils {
      * @param data An array of characters containing hexidecimal digits
      * @return A byte array containing binary data decoded from
      *         the supplied char array.
-     * @throws IgniteCheckedException Thrown if an odd number or illegal of 
characters is supplied.
+     * @throws IgniteException Thrown if an odd number or illegal of 
characters is supplied.
      */
-    public static byte[] decodeHex(char[] data) throws IgniteCheckedException {
+    public static byte[] decodeHex(char[] data) throws IgniteException {
 
         int len = data.length;
 
         if ((len & 0x01) != 0)
-            throw new IgniteCheckedException("Odd number of characters.");
+            throw new IgniteException("Odd number of characters.");
 
         byte[] out = new byte[len >> 1];
 
@@ -8571,15 +8571,15 @@ public abstract class GridUtils {
      * Converts a hexadecimal character to an integer.
      *
      * @param ch A character to convert to an integer digit
-     * @param index The index of the character in the source
+     * @param idx The index of the character in the source
      * @return An integer
-     * @throws IgniteCheckedException Thrown if ch is an illegal hex character
+     * @throws IgniteException Thrown if ch is an illegal hex character
      */
-    public static int toDigit(char ch, int index) throws 
IgniteCheckedException {
+    public static int toDigit(char ch, int idx) throws IgniteException {
         int digit = Character.digit(ch, 16);
 
         if (digit == -1)
-            throw new IgniteCheckedException("Illegal hexadecimal character " 
+ ch + " at index " + index);
+            throw new IgniteException("Illegal hexadecimal character " + ch + 
" at index " + idx);
 
         return digit;
     }
@@ -9027,4 +9027,45 @@ public abstract class GridUtils {
 
         return list;
     }
+
+    /**
+     * Propagates {@code throwable} as-is if it is an instance of {@link 
RuntimeException} or {@link Error}, or else as
+     * a last resort, wraps it in a {@code RuntimeException} then propagates.
+     * <p>
+     * This method always throws an exception. The {@code RuntimeException} 
return type is only for client code to make
+     * Java type system happy in case a return value is required by the 
enclosing method.
+     * @param throwable
+     * @return nothing will ever be returned; this return type is only for 
your convenience.
+     */
+    public static IgniteException wrap(Throwable throwable) {
+        if (throwable instanceof Error)
+            throw (Error)throwable;
+
+        if (throwable instanceof RuntimeException)
+            throw (RuntimeException)throwable;
+
+
+        throw new IgniteException(throwable);
+    }
+
+    /**
+     * Propagates {@code throwable} as-is if it is an instance of {@link 
RuntimeException} or {@link Error}, or else as
+     * a last resort, wraps it in a {@code RuntimeException} then propagates.
+     * <p>
+     * This method always throws an exception. The {@code RuntimeException} 
return type is only for client code to make
+     * Java type system happy in case a return value is required by the 
enclosing method.
+     * @param throwable
+     * @param msg Message for wrapping exception.
+     * @return nothing will ever be returned; this return type is only for 
your convenience.
+     */
+    public static IgniteException wrap(Throwable throwable, String msg) {
+        if (throwable instanceof Error)
+            throw (Error)throwable;
+
+        if (throwable instanceof RuntimeException)
+            throw (RuntimeException)throwable;
+
+
+        throw new IgniteException(msg, throwable);
+    }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
index bf89359..2d7dfde 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
@@ -98,7 +98,7 @@ public class GridCompoundFuture<T, R> extends 
GridFutureAdapter<R> {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws IgniteCheckedException {
+    @Override public boolean cancel() {
         if (onCancelled()) {
             for (IgniteFuture<T> fut : futs)
                 fut.cancel();
@@ -170,7 +170,7 @@ public class GridCompoundFuture<T, R> extends 
GridFutureAdapter<R> {
             try {
                 fut.cancel();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 onDone(e);
             }
     }
@@ -342,7 +342,7 @@ public class GridCompoundFuture<T, R> extends 
GridFutureAdapter<R> {
 
                 err.compareAndSet(null, e);
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 if (!ignoreFailure(e))
                     U.error(log, "Failed to execute compound future reducer: " 
+ this, e);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
index 346978c..485d4bd 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
@@ -220,7 +220,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws IgniteCheckedException {
+    @Override public boolean cancel() throws IgniteException {
         return embedded.cancel();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
index 5f98641..b384e09 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
@@ -141,7 +141,7 @@ public class GridFinishedFuture<T> implements 
IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public T get() throws IgniteCheckedException {
+    @Override public T get() throws IgniteException {
         if (err != null)
             throw U.cast(err);
 
@@ -149,12 +149,12 @@ public class GridFinishedFuture<T> implements 
IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout) throws IgniteCheckedException {
+    @Override public T get(long timeout) throws IgniteException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout, TimeUnit unit) throws 
IgniteCheckedException {
+    @Override public T get(long timeout, TimeUnit unit) throws IgniteException 
{
         return get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
index 663cf87..e4fde11 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
@@ -117,7 +117,7 @@ public class GridFinishedFutureEx<T> implements 
IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public T get() throws IgniteCheckedException {
+    @Override public T get() throws IgniteException {
         if (err != null)
             throw U.cast(err);
 
@@ -125,12 +125,12 @@ public class GridFinishedFutureEx<T> implements 
IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout) throws IgniteCheckedException {
+    @Override public T get(long timeout) throws IgniteException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout, TimeUnit unit) throws 
IgniteCheckedException {
+    @Override public T get(long timeout, TimeUnit unit) throws IgniteException 
{
         return get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
index 7d675a7..3991d39 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
@@ -186,7 +186,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws IgniteCheckedException {
+    @Override public R get() throws IgniteException {
         checkValid();
 
         try {
@@ -209,13 +209,13 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws IgniteCheckedException {
+    @Override public R get(long timeout) throws IgniteException {
         // Do not replace with static import, as it may not compile.
         return get(timeout, TimeUnit.MILLISECONDS);
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws 
IgniteCheckedException {
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteException 
{
         A.ensure(timeout >= 0, "timeout cannot be negative: " + timeout);
         A.notNull(unit, "unit");
 
@@ -236,9 +236,8 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
      * @return Result.
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout 
reached before computation completed.
-     * @throws IgniteCheckedException If error occurred.
      */
-    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteCheckedException {
+    @Nullable protected R get0(long nanosTimeout) throws InterruptedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
             throw new IgniteFutureTimeoutException("Timeout was reached before 
computation completed.");
 
@@ -388,7 +387,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
      * and call {@link #onCancelled()} callback explicitly if cancellation
      * indeed did happen.
      */
-    @Override public boolean cancel() throws IgniteCheckedException {
+    @Override public boolean cancel() {
         checkValid();
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
index 84f9eb5..5749061 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
@@ -135,7 +135,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws IgniteCheckedException {
+    @Override public R get() throws IgniteException {
         checkValid();
 
         try {
@@ -158,13 +158,13 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws IgniteCheckedException {
+    @Override public R get(long timeout) throws IgniteException {
         // Do not replace with static import, as it may not compile.
         return get(timeout, TimeUnit.MILLISECONDS);
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws 
IgniteCheckedException {
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteException 
{
         A.ensure(timeout >= 0, "timeout cannot be negative: " + timeout);
         A.notNull(unit, "unit");
 
@@ -185,9 +185,9 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
      * @return Result.
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout 
reached before computation completed.
-     * @throws IgniteCheckedException If error occurred.
+     * @throws IgniteException If error occurred.
      */
-    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteCheckedException {
+    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
             throw new IgniteFutureTimeoutException("Timeout was reached before 
computation completed.");
 
@@ -334,7 +334,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
      * and call {@link #onCancelled()} callback explicitly if cancellation
      * indeed did happen.
      */
-    @Override public boolean cancel() throws IgniteCheckedException {
+    @Override public boolean cancel() throws IgniteException {
         checkValid();
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
index f19cc45..cbb3215 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
@@ -56,7 +56,7 @@ public class GridifyJobAdapter extends ComputeJobAdapter {
      * @return {@inheritDoc}
      * @throws IgniteCheckedException {@inheritDoc}
      */
-    @Override public Object execute() throws IgniteCheckedException {
+    @Override public Object execute() throws IgniteException {
         GridifyArgument arg = argument(0);
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/lang/GridCloseableIterator.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridCloseableIterator.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridCloseableIterator.java
index 624feda..7bbf825 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridCloseableIterator.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridCloseableIterator.java
@@ -41,9 +41,9 @@ public interface GridCloseableIterator<T> extends 
GridIterator<T>, IgniteSpiClos
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.
      *
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
-    @Override public void close() throws IgniteCheckedException;
+    @Override public void close() throws IgniteException;
 
     /**
      * Checks if iterator has been closed.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/lang/GridComputeJobWrapper.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridComputeJobWrapper.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridComputeJobWrapper.java
index 3fe0590..e16b38d 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridComputeJobWrapper.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridComputeJobWrapper.java
@@ -87,7 +87,7 @@ public class GridComputeJobWrapper extends 
GridMetadataAwareAdapter implements C
     }
 
     /** {@inheritDoc} */
-    @Override public Object execute() throws IgniteCheckedException {
+    @Override public Object execute() throws IgniteException {
         return job.execute();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafeMap.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafeMap.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafeMap.java
index 10a7511..120da0b 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafeMap.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafeMap.java
@@ -410,7 +410,7 @@ public class GridUnsafeMap<K> implements GridOffHeapMap<K> {
                 throw new UnsupportedOperationException();
             }
 
-            @Override protected void onClose() throws IgniteCheckedException {
+            @Override protected void onClose() throws IgniteException {
                 if (curIt != null)
                     curIt.close();
             }
@@ -428,12 +428,12 @@ public class GridUnsafeMap<K> implements 
GridOffHeapMap<K> {
                 try {
                     advance();
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace(); // Should never happen.
                 }
             }
 
-            private void advance() throws IgniteCheckedException {
+            private void advance() throws IgniteException {
                 curIt = null;
 
                 while (idx < segs.length) {
@@ -448,7 +448,7 @@ public class GridUnsafeMap<K> implements GridOffHeapMap<K> {
                 curIt = null;
             }
 
-            @Override protected T onNext() throws IgniteCheckedException {
+            @Override protected T onNext() throws IgniteException {
                 if (curIt == null)
                     throw new NoSuchElementException();
 
@@ -471,7 +471,7 @@ public class GridUnsafeMap<K> implements GridOffHeapMap<K> {
                 throw new UnsupportedOperationException();
             }
 
-            @Override protected void onClose() throws IgniteCheckedException {
+            @Override protected void onClose() throws IgniteException {
                 if (curIt != null)
                     curIt.close();
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafePartitionedMap.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafePartitionedMap.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafePartitionedMap.java
index 27b9b67..4fc40f5 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafePartitionedMap.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/offheap/unsafe/GridUnsafePartitionedMap.java
@@ -312,7 +312,7 @@ public class GridUnsafePartitionedMap implements 
GridOffHeapPartitionedMap {
                 throw new UnsupportedOperationException();
             }
 
-            @Override protected void onClose() throws IgniteCheckedException {
+            @Override protected void onClose() throws IgniteException {
                 if (curIt != null)
                     curIt.close();
             }
@@ -375,7 +375,7 @@ public class GridUnsafePartitionedMap implements 
GridOffHeapPartitionedMap {
                 throw new UnsupportedOperationException();
             }
 
-            @Override protected void onClose() throws IgniteCheckedException {
+            @Override protected void onClose() throws IgniteException {
                 if (curIt != null)
                     curIt.close();
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorkerFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorkerFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorkerFuture.java
index 6e41518..4fbbb6c 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorkerFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorkerFuture.java
@@ -40,7 +40,7 @@ public class GridWorkerFuture<T> extends GridFutureAdapter<T> 
{
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws IgniteCheckedException {
+    @Override public boolean cancel() throws IgniteException {
         assert w != null;
 
         if (!onCancelled())

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/marshaller/optimized/GridOptimizedMarshallerTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/marshaller/optimized/GridOptimizedMarshallerTest.java
 
b/modules/core/src/test/java/org/apache/ignite/marshaller/optimized/GridOptimizedMarshallerTest.java
index c905d0c..8583dc2 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/marshaller/optimized/GridOptimizedMarshallerTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/marshaller/optimized/GridOptimizedMarshallerTest.java
@@ -625,7 +625,7 @@ public class GridOptimizedMarshallerTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object execute() throws IgniteCheckedException {
+        @Override public Object execute() throws IgniteException {
             assert false;
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
index 7817c02..f954f44 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
@@ -77,29 +77,29 @@ public class GridTestCollisionTaskSession implements 
ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public void saveCheckpoint(String key, Object state) throws 
IgniteCheckedException {
+    @Override public void saveCheckpoint(String key, Object state) throws 
IgniteException {
         assert false : "Not implemented";
     }
 
     @Override public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout)
-        throws IgniteCheckedException {
+        throws IgniteException {
         assert false : "Not implemented";
     }
 
     @Override public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout,
-        boolean overwrite) throws IgniteCheckedException {
+        boolean overwrite) throws IgniteException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T loadCheckpoint(String key) throws 
IgniteCheckedException {
+    @Override public <T> T loadCheckpoint(String key) throws IgniteException {
         assert false : "Not implemented";
 
         return null;
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeCheckpoint(String key) throws 
IgniteCheckedException {
+    @Override public boolean removeCheckpoint(String key) throws 
IgniteException {
         assert false : "Not implemented";
 
         return false;
@@ -139,7 +139,7 @@ public class GridTestCollisionTaskSession implements 
ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public Collection<ComputeJobSibling> refreshJobSiblings() throws 
IgniteCheckedException {
+    @Override public Collection<ComputeJobSibling> refreshJobSiblings() throws 
IgniteException {
         return getJobSiblings();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
index 3684f5e..2e579d0 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
@@ -169,7 +169,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
     @ComputeTaskSessionFullSupport
     private static class Task extends ComputeTaskSplitAdapter<Void, Void> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Void arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Void arg) throws IgniteException {
             return Collections.singleton(new ComputeJobAdapter() {
                 @Nullable @Override public Object execute() {
                     return null;
@@ -178,7 +178,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteException {
             return null;
         }
     }
@@ -189,16 +189,16 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
     @ComputeTaskSessionFullSupport
     private static class FailTask extends ComputeTaskSplitAdapter<Void, Void> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Void arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Void arg) throws IgniteException {
             return Collections.singleton(new ComputeJobAdapter() {
-                @Nullable @Override public Object execute() throws 
IgniteCheckedException {
+                @Nullable @Override public Object execute() throws 
IgniteException {
                     throw new IgniteCheckedException("Task failed.");
                 }
             });
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/spi/deployment/local/GridLocalDeploymentSpiSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/deployment/local/GridLocalDeploymentSpiSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/deployment/local/GridLocalDeploymentSpiSelfTest.java
index a1ef3a7..8f14b14 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/deployment/local/GridLocalDeploymentSpiSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/deployment/local/GridLocalDeploymentSpiSelfTest.java
@@ -148,12 +148,12 @@ public class GridLocalDeploymentSpiSelfTest extends 
GridSpiAbstractTest<LocalDep
     @ComputeTaskName(value="GridDeploymentTestTask")
     public class GridDeploymentTestTask extends 
ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteException {
             return null;
         }
     }
@@ -165,12 +165,12 @@ public class GridLocalDeploymentSpiSelfTest extends 
GridSpiAbstractTest<LocalDep
     @ComputeTaskName(value="GridDeploymentTestTask")
     public class GridDeploymentTestTask1 extends 
ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/spi/failover/GridFailoverTestContext.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/failover/GridFailoverTestContext.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/failover/GridFailoverTestContext.java
index 7733d86..04c3451 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/failover/GridFailoverTestContext.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/failover/GridFailoverTestContext.java
@@ -56,7 +56,7 @@ public class GridFailoverTestContext implements 
FailoverContext {
     }
 
     /** {@inheritDoc} */
-    @Override public ClusterNode getBalancedNode(List<ClusterNode> grid) 
throws IgniteCheckedException {
+    @Override public ClusterNode getBalancedNode(List<ClusterNode> grid) 
throws IgniteException {
         return grid.get(RAND.nextInt(grid.size()));
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
index 2fdbe53..060b6e4 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
@@ -669,7 +669,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Nullable @Override public String onAdded(StreamerIndexEntry<String, 
String, String> entry, String evt)
-            throws IgniteCheckedException {
+            throws IgniteException {
             throw new IgniteCheckedException("Unique key violation: " + evt);
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/GridTestJob.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/GridTestJob.java 
b/modules/core/src/test/java/org/gridgain/grid/GridTestJob.java
index c86cce4..49b6365 100644
--- a/modules/core/src/test/java/org/gridgain/grid/GridTestJob.java
+++ b/modules/core/src/test/java/org/gridgain/grid/GridTestJob.java
@@ -34,7 +34,7 @@ public class GridTestJob extends ComputeJobAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public String execute() throws IgniteCheckedException {
+    @Override public String execute() throws IgniteException {
         if (log.isDebugEnabled())
             log.debug("Executing job [job=" + this + ", arg=" + argument(0) + 
']');
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/GridTestTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/GridTestTask.java 
b/modules/core/src/test/java/org/gridgain/grid/GridTestTask.java
index a2958f8..8664f88 100644
--- a/modules/core/src/test/java/org/gridgain/grid/GridTestTask.java
+++ b/modules/core/src/test/java/org/gridgain/grid/GridTestTask.java
@@ -37,7 +37,7 @@ public class GridTestTask extends 
ComputeTaskSplitAdapter<Object, Object> {
     }
 
     /** {@inheritDoc} */
-    @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+    @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
         if (log.isDebugEnabled())
             log.debug("Reducing task [task=" + this + ", results=" + results + 
']');
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java 
b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
index 6765221..e740d64 100644
--- a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
+++ b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
@@ -164,31 +164,31 @@ public class GridTestTaskSession implements 
ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public void saveCheckpoint(String key, Object state) throws 
IgniteCheckedException {
+    @Override public void saveCheckpoint(String key, Object state) throws 
IgniteException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
     @Override public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout)
-        throws IgniteCheckedException {
+        throws IgniteException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
     @Override public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout,
-        boolean overwrite) throws IgniteCheckedException {
+        boolean overwrite) throws IgniteException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T loadCheckpoint(String key) throws 
IgniteCheckedException {
+    @Override public <T> T loadCheckpoint(String key) throws IgniteException {
         assert false : "Not implemented";
 
         return null;
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeCheckpoint(String key) throws 
IgniteCheckedException {
+    @Override public boolean removeCheckpoint(String key) throws 
IgniteException {
         assert false : "Not implemented";
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java 
b/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
index 62e3b4b..f8f42c5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
@@ -30,9 +30,9 @@ public class GridWeakIterator<T> extends 
WeakReference<Iterator<T>> {
     /**
      * Closes iterator.
      *
      * @throws IgniteCheckedException If failed.
      */
-    public void close() throws IgniteCheckedException {
+    public void close() throws IgniteException {
         it.close();
     }
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
----------------------------------------------------------------------
@@ -30,9 +30,9 @@ public class GridWeakIterator<T> extends 
      * Closes iterator.
      *
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
index d392ca3..8be4c9b 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
@@ -122,7 +122,7 @@ public class GridAlwaysFailoverSpiFailSelfTest extends 
GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res,
-            List<ComputeJobResult> received) throws IgniteCheckedException {
+            List<ComputeJobResult> received) throws IgniteException {
             if (res.getException() != null)
                 return ComputeJobResultPolicy.FAILOVER;
 
@@ -145,7 +145,7 @@ public class GridAlwaysFailoverSpiFailSelfTest extends 
GridCommonAbstractTest {
         GridTestFailoverJob(IgniteCheckedException ex) { super(ex); }
 
         /** {@inheritDoc} */
-        @Override public IgniteCheckedException execute() throws 
IgniteCheckedException {
+        @Override public IgniteCheckedException execute() throws 
IgniteException {
             throw this.<IgniteCheckedException>argument(0);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
index c20926e..860d4f8 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
@@ -65,7 +65,7 @@ public class GridCancelOnGridStopSelfTest extends 
GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, @Nullable String arg)
-            throws IgniteCheckedException {
+            throws IgniteException {
             for (ClusterNode node : subgrid) {
                 if (node.id().equals(locId)) {
                     return Collections.singletonMap(new ComputeJob() {
@@ -73,7 +73,7 @@ public class GridCancelOnGridStopSelfTest extends 
GridCommonAbstractTest {
                             cancelCall = true;
                         }
 
-                        @Override public Serializable execute() throws 
IgniteCheckedException {
+                        @Override public Serializable execute() throws 
IgniteException {
                             cnt.countDown();
 
                             try {
@@ -93,7 +93,7 @@ public class GridCancelOnGridStopSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Nullable @Override public Void reduce(List<ComputeJobResult> results) 
throws IgniteException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
index e46813c..91ad116 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
@@ -117,7 +117,7 @@ public class GridCancelUnusedJobSelfTest extends 
GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             if (log.isInfoEnabled())
                 log.info("Splitting job [job=" + this + ", gridSize=" + 
gridSize + ", arg=" + arg + ']');
 
@@ -135,7 +135,7 @@ public class GridCancelUnusedJobSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteException {
             if (log.isInfoEnabled())
                 log.info("Reducing job [job=" + this + ", results=" + results 
+ ']');
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
index afcf4ac..d4ab8fc 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
@@ -122,7 +122,7 @@ public class GridCancelledJobsMetricsSelfTest extends 
GridCommonAbstractTest {
      */
     private static final class GridCancelledJob extends ComputeJobAdapter {
         /** {@inheritDoc} */
-        @Override public String execute() throws IgniteCheckedException {
+        @Override public String execute() throws IgniteException {
             X.println("Executing job.");
 
             try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
index 65c1a0e..0f66aaf 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
@@ -97,7 +97,7 @@ public class GridContinuousJobAnnotationSelfTest extends 
GridCommonAbstractTest
         private ComputeTaskContinuousMapper mapper;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteException {
             try {
                 mapper.send(((Class<ComputeJob>)arg).newInstance());
             }
@@ -110,7 +110,7 @@ public class GridContinuousJobAnnotationSelfTest extends 
GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received)
-            throws IgniteCheckedException {
+            throws IgniteException {
             if (res.getException() != null) {
                 if (res.getException() instanceof 
ComputeUserUndeclaredException)
                     throw new IgniteCheckedException("Job threw unexpected 
exception.", res.getException());
@@ -122,7 +122,7 @@ public class GridContinuousJobAnnotationSelfTest extends 
GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 1 : "Unexpected result count: " + 
results.size();
 
             return null;
@@ -171,7 +171,7 @@ public class GridContinuousJobAnnotationSelfTest extends 
GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws IgniteCheckedException {
+        @Override public Serializable execute() throws IgniteException {
             X.println("Execute TestJob [this=" + this + ", identity=" + 
System.identityHashCode(this) +
                 ", flag=" + flag + "]");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
index 9d27620..af09425 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
@@ -69,13 +69,13 @@ public class GridContinuousJobSiblingsSelfTest extends 
GridCommonAbstractTest {
         private volatile int jobCnt;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             return Collections.singleton(new TestJob(++jobCnt));
         }
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received)
-            throws IgniteCheckedException {
+            throws IgniteException {
             if (res.getException() != null)
                 throw new IgniteCheckedException("Job resulted in error: " + 
res, res.getException());
 
@@ -91,7 +91,7 @@ public class GridContinuousJobSiblingsSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assertEquals(JOB_COUNT, results.size());
 
             return null;
@@ -116,7 +116,7 @@ public class GridContinuousJobSiblingsSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws IgniteCheckedException {
+        @Override public Serializable execute() throws IgniteException {
             assert ses != null;
             assert argument(0) != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
index 15ca5ff..5b15269 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
@@ -142,7 +142,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         private int cnt;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Boolean arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Boolean arg) throws IgniteException {
             assert mapper != null;
             assert arg != null;
 
@@ -163,7 +163,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received) throws IgniteCheckedException {
+        @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received) throws IgniteException {
             assert mapper != null;
             assert res.getException() == null : "Unexpected exception: " + 
res.getException();
 
@@ -181,7 +181,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 10 : "Unexpected result count: " + 
results.size();
 
             log.info("Called reduce() method [results=" + results + ']');
@@ -212,7 +212,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws IgniteCheckedException {
+        @Override public Serializable execute() throws IgniteException {
             Integer i = argument(0);
 
             return i != null ? i : 0;
@@ -236,7 +236,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             ses.addAttributeListener(new ComputeTaskSessionAttributeListener() 
{
                 @Override public void onAttributeSet(Object key, Object val) {
                     if (key instanceof String) {
@@ -267,7 +267,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assertEquals(JOB_COUNT * JOB_COUNT, results.size());
 
             return null;
@@ -296,7 +296,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws IgniteCheckedException {
+        @Override public Serializable execute() throws IgniteException {
             Integer i = argument(0);
 
             int arg = i != null ? i : 0;
@@ -318,7 +318,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         private int cnt;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteException {
             mapper.send(new TestJob(++cnt));
 
             try {
@@ -334,7 +334,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return results == null ? 0 : results.size();
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
index 012a833..0af0b2e 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
@@ -100,14 +100,14 @@ public class GridDeploymentMultiThreadedSelfTest extends 
GridCommonAbstractTest
      */
     private static class GridDeploymentTestTask extends 
ComputeTaskAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteException {
             assert false;
 
             return Collections.emptyMap();
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
index 33858b1..a986dae 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
@@ -355,7 +355,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg)
-            throws IgniteCheckedException {
+            throws IgniteException {
             Map<ComputeJobAdapter, ClusterNode> map = new 
HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -373,7 +373,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return null;
         }
     }
@@ -388,7 +388,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteException {
             Map<ComputeJobAdapter, ClusterNode> map = new 
HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -405,7 +405,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return null;
         }
     }
@@ -420,7 +420,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, Object arg) throws IgniteException {
             Map<ComputeJobAdapter, ClusterNode> map = new 
HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -438,7 +438,7 @@ public class GridDeploymentSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
index 0c0fa14..8ae2215 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
@@ -340,7 +340,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends 
GridCommonAbstractTe
         private ComputeTaskSession taskSes;
 
         /** {@inheritDoc} */
-        @Override public String execute() throws IgniteCheckedException {
+        @Override public String execute() throws IgniteException {
             assert taskSes != null;
 
             taskSes.saveCheckpoint("testCheckpoint", "TestState");
@@ -394,7 +394,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends 
GridCommonAbstractTe
         private ComputeTaskSession taskSes;
 
         /** {@inheritDoc} */
-        @Override public String execute() throws IgniteCheckedException {
+        @Override public String execute() throws IgniteException {
             assert taskSes != null;
 
             taskSes.saveCheckpoint("testAllCheckpoint", "CheckpointTestState");
@@ -411,12 +411,12 @@ public class GridEventStorageCheckAllEventsSelfTest 
extends GridCommonAbstractTe
     @ComputeTaskSessionFullSupport
     private static class GridAllEventsTestTask extends 
ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             return Collections.singleton((ComputeJob)arg);
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteException {
             assert results != null;
             assert results.size() == 1;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
index 1b96031..2f702b7 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
@@ -192,12 +192,12 @@ public class GridEventStorageSelfTest extends 
GridCommonAbstractTest {
      */
     private static class GridEventTestTask extends 
ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteCheckedException {
+        @Override protected Collection<? extends ComputeJob> split(int 
gridSize, Object arg) throws IgniteException {
             return Collections.singleton(new GridEventTestJob());
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) 
throws IgniteException {
             assert results != null;
             assert results.size() == 1;
 
@@ -210,7 +210,7 @@ public class GridEventStorageSelfTest extends 
GridCommonAbstractTest {
      */
     private static class GridEventTestJob extends ComputeJobAdapter {
         /** {@inheritDoc} */
-        @Override public String execute() throws IgniteCheckedException {
+        @Override public String execute() throws IgniteException {
             return "GridEventTestJob-test-event.";
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
index 4b5a5fa..def4d0a 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
@@ -395,7 +395,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends 
GridCommonAbstractTe
         private UUID locId;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteException {
             Map<ComputeJobAdapter, ClusterNode> map = new 
HashMap<>(subgrid.size());
 
             boolean ignoreLocNode = false;
@@ -417,7 +417,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends 
GridCommonAbstractTe
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws 
IgniteException {
             return results.get(0).getData();
         }
     }
@@ -432,7 +432,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends 
GridCommonAbstractTe
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws IgniteCheckedException {
+        @Override public Serializable execute() throws IgniteException {
             if (log.isInfoEnabled())
                 log.info("Executing grid job: " + this);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
index c695b84..05bf11a 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
@@ -120,7 +120,7 @@ public class GridFailoverCustomTopologySelfTest extends 
GridCommonAbstractTest {
         private UUID locNodeId;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteException {
             assert locNodeId != null;
 
             if (log.isInfoEnabled())
@@ -140,7 +140,7 @@ public class GridFailoverCustomTopologySelfTest extends 
GridCommonAbstractTest {
 
                 /** {@inheritDoc} */
                 @SuppressWarnings("NakedNotify")
-                @Override public Serializable execute() throws 
IgniteCheckedException {
+                @Override public Serializable execute() throws IgniteException 
{
                     assert nodeId != null;
 
                     if (!nodeId.equals(argument(0))) {
@@ -164,7 +164,7 @@ public class GridFailoverCustomTopologySelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public String reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public String reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 1;
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
index b0fba9b..e52bae3 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
@@ -76,7 +76,7 @@ public class GridFailoverSelfTest extends 
GridCommonAbstractTest {
         private ComputeTaskSession ses;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteException {
             ses.setAttribute("fail", true);
 
             nodeRef.set(subgrid.get(0));
@@ -87,7 +87,7 @@ public class GridFailoverSelfTest extends 
GridCommonAbstractTest {
                 private UUID locId;
 
                 /** {@inheritDoc} */
-                @Override public Serializable execute() throws 
IgniteCheckedException {
+                @Override public Serializable execute() throws IgniteException 
{
                     boolean fail;
 
                     try {
@@ -115,7 +115,7 @@ public class GridFailoverSelfTest extends 
GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res,
-            List<ComputeJobResult> received) throws IgniteCheckedException {
+            List<ComputeJobResult> received) throws IgniteException {
             if (res.getException() != null && !(res.getException() instanceof 
ComputeUserUndeclaredException)) {
                 assert res.getNode().id().equals(nodeRef.get().id());
 
@@ -128,7 +128,7 @@ public class GridFailoverSelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 1;
 
             assert nodeRef.get() != null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
index 893b213..27c3cd5 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
@@ -186,7 +186,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends 
GridCommonAbstractTes
         private ComputeTaskSession ses;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteException {
             ses.setAttribute("fail", true);
 
             return Collections.singletonMap(new ComputeJobAdapter(arg) {
@@ -197,7 +197,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends 
GridCommonAbstractTes
                 /** {@inheritDoc} */
                 @SuppressWarnings({"RedundantTypeArguments"})
                 @Override
-                public Serializable execute() throws IgniteCheckedException {
+                public Serializable execute() throws IgniteException {
                     boolean fail;
 
                     try {
@@ -221,7 +221,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends 
GridCommonAbstractTes
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received)
-                throws IgniteCheckedException {
+                throws IgniteException {
             if (res.getException() != null && !(res.getException() instanceof 
ComputeUserUndeclaredException))
                 return ComputeJobResultPolicy.FAILOVER;
 
@@ -229,7 +229,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends 
GridCommonAbstractTes
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 1;
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
index d704f03..eb7b69c 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
@@ -109,7 +109,7 @@ public class GridFailoverTopologySelfTest extends 
GridCommonAbstractTest {
         private boolean jobFailedOver;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
+        @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, String arg) throws IgniteException {
             assert locNodeId != null;
 
             ClusterNode remoteNode = null;
@@ -120,14 +120,14 @@ public class GridFailoverTopologySelfTest extends 
GridCommonAbstractTest {
             }
 
             return Collections.singletonMap(new ComputeJobAdapter(arg) {
-                @Override public Serializable execute() throws 
IgniteCheckedException {
+                @Override public Serializable execute() throws IgniteException 
{
                     throw new IgniteCheckedException("Job exception.");
                 }
             }, remoteNode);
         }
 
         /** {@inheritDoc} */
-        @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received) throws IgniteCheckedException {
+        @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> received) throws IgniteException {
             if (res.getException() != null && !jobFailedOver) {
                 jobFailedOver = true;
 
@@ -138,7 +138,7 @@ public class GridFailoverTopologySelfTest extends 
GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws 
IgniteException {
             assert results.size() == 1;
 
             return results.get(0).getData();

Reply via email to